1.0.0 API documentation: matrix_double2x2_precision.hpp Source File

| 1.0.0 API documentation

matrix_double2x2_precision.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat2x2.hpp"
6
7 namespace glm
8 {
11
16 typedef mat<2, 2, double, lowp> lowp_dmat2;
17
22 typedef mat<2, 2, double, mediump> mediump_dmat2;
23
28 typedef mat<2, 2, double, highp> highp_dmat2;
29
34 typedef mat<2, 2, double, lowp> lowp_dmat2x2;
35
40 typedef mat<2, 2, double, mediump> mediump_dmat2x2;
41
46 typedef mat<2, 2, double, highp> highp_dmat2x2;
47
49 }//namespace glm
glm::mediump_dmat2
mat< 2, 2, double, mediump > mediump_dmat2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:22
glm::highp_dmat2x2
mat< 2, 2, double, highp > highp_dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:46
glm::lowp_dmat2x2
mat< 2, 2, double, lowp > lowp_dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double2x2_precision.hpp:34
glm::lowp_dmat2
mat< 2, 2, double, lowp > lowp_dmat2
2 columns of 2 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double2x2_precision.hpp:16
glm::mediump_dmat2x2
mat< 2, 2, double, mediump > mediump_dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:40
glm::highp_dmat2
mat< 2, 2, double, highp > highp_dmat2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:28